$ifndef _ADIN_INC_
$define _ADIN_INC_
'
' Replacement routine for the Adin command with enhanced 14-bit core devices
'
    #disable ADIn                       ' Disable the compiler's ADin library routine

    Dim PP7 As Byte System              ' \ Create two compiler system variables for ADin to use
    Dim PP7H As Byte System             ' /

    GoTo _Adin_Main_                    ' Jump over the routine

'--------------------------------------------------------------------------------
' ADin replacement routine for Enhanced 14-bit core devices containing ADCON1
' Input     : WREG holds the channel of interest
' Output    : PP7 and WREG holds an 8-bit result, or PP7/PP7H for a 10 or 12-bit result
' Notes     : If Adin declares are not used in the main program the routine will default to FRC at 10-bits with no delay
'
__adin_:
    WREG = WREG & $1F                   ' Mask the channel bits
    ADCON0 = WREG << 2                  ' Move the channel into its correct position
$ifdef _ADCON1                          ' Does the device contain the ADCON1 register?
    #ifSym __ADIN_TAD                   ' Yes. So has the Adin_Tad declare been used in the program?
        WREG = ADCON1                   ' Yes. So load ADCON1 into WREG
        WREG = WREG & $8F               ' Mask the Tad bits
        WREG = __ADIN_TAD << 4          ' Or in the Adin_Tad declare value
        ADCON1 = ADCON1 | WREG          ' Transfer back into ADCON1
    #endIfSym
    #ifnSym __ADIN_TAD                  ' Has the Adin_Tad declare been used in the program?
        WREG = ADCON1                   ' No. So load ADCON1 into WREG
        WREG = WREG & $8F               ' Mask the Tad bits
        WREG = 3 << 4                   ' Or in a Tad value for FRC
        ADCON1 = ADCON1 | WREG          ' Transfer back into ADCON1
    #endIfSym
    Set ADCON0bits_ADON                 ' Turn on the ADC
$endif

#ifSym __ADIN_DELAY                     ' Has the Adin_Stime declare been used in the program?
    DelayUS __ADIN_DELAY                ' Yes. So delay for Stime
#endIfSym
    Set ADCON0bits_GO_NOT_DONE          ' Start a conversion
    #ifdef WatchDog_Req
        Clrwdt                          ' Keep the watchdog happy (if enabled)
    #endif
    While ADCON0bits_GO_NOT_DONE = 1    ' \ Wait for a conversion to complete
    Wend                                ' /
#ifSym __ADIN_RES                       ' Has the Adin_Res declare been used in the program?
    #if(__ADIN_RES <= 8)                ' Yes. So are we expecting an 8-bit result?
        PP7H = 0                        ' Yes. So setup for an 8-bit result
    #else                               ' Otherwise...
        PP7H = ADRESH                   ' Setup for a 10 or 12-bit result
    #endif
#endIfSym
#ifnSym __ADIN_RES                      ' Has the Adin_Res declare been used in the program?
    PP7H = ADRESH                       ' No. So setup for a 10 or 12-bit result
#endIfSym
    WREG = ADRESL                       ' ADRESL to WREG
    PP7 = WREG                          ' Place result into PP7
    Return
'------------------------------------------------------------------------------------------
_Adin_Main_:

$endif  ' _ADIN_INC_


